#[non_exhaustive]pub enum ScriptArgsError {
Decode(FeltReprError),
NonZeroPadding,
TrailingData,
NonWordMultipleLength,
AdviceProviderUnavailable,
}Expand description
Failure decoding transaction-script arguments from the TX_SCRIPT_ARGS word.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Decode(FeltReprError)
A value failed to decode from its felt representation.
NonZeroPadding
A felt in the zero-padding region of the encoding was not zero.
TrailingData
A whole word or more of data remained after decoding the value (commitment mode).
NonWordMultipleLength
The advice value’s length was not a whole number of words (commitment mode).
Commitment-mode decoding was attempted without the Miden VM’s advice provider
(i.e. off-chain). Word-mode decoding and decode_preimage work everywhere.